@@ -1,36 +1,40 @@
 package Cog::Base;
-use Mouse;
-use JSON;
+use Mo;
 
 # System singleton object pointers.
 my $app;
 my $config;
-my $content;
 my $maker;
 my $runner;
-my $store;
 my $webapp;
-my $view;
 my $json;
 
 # The config reference must be initialized at startup.
-sub initialize {
-    $app ||= $_[1];
-    $config ||= $_[2];
-}
+$Cog::Base::initialize = sub {
+    $app ||= $_[0];
+    $config ||= $_[1];
+};
 
 # The accessors to common singleton objects are kept in single file
 # scoped lexicals, so that every Cog::Base subclass can access them
 # without needing to store them in their objects. This keeps things
 # clean and fast, and avoids needless circular refs.
-sub app { $app }
+my $singleton = sub {
+    my ($type) = @_;
+    my $method = lc($type) . "_class";
+    my $class = $app->$method
+        or die "Can't determine class for '$type'";
+    unless (UNIVERSAL::isa($class, 'Cog::Base')) {
+        eval "require $class; 1" or die $@;
+    }
+    return $class->new();
+};
+
+sub app    { $app }
 sub config { $config }
-sub content { $content || ($content = $config->content) }
-sub maker { $maker || ($maker = $config->maker) }
-sub runner { $runner || ($runner = $config->runner) }
-sub store { $store || ($store = $config->store) }
-sub webapp { $webapp || ($webapp = $config->webapp) }
-sub view { $view || ($view = $config->view) }
+sub maker  { $maker  || ($maker  = $singleton->('Maker')) }
+sub runner { $runner || ($runner = $singleton->('Runner')) }
+sub webapp { $webapp || ($webapp = $singleton->('WebApp')) }
 
 # Cog plugins need to know their distribution name. This name is used to
 # locate shared files using File::ShareDir and other methods.
@@ -59,6 +63,7 @@ sub DISTNAME {
 # Access to a set up JSON object
 sub json {
     $json ||= do {
+        require JSON;
         my $j = JSON->new;
         $j->allow_blessed;
         $j->convert_blessed;
